@@ -12,12 +12,8 @@
 #include "oxygendetectwidget.h"
 
 #if OXYGEN_HAVE_X11
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-#include <QX11Info>
-#else
 #include <private/qtx11extras_p.h>
 #endif
-#endif
 
 namespace Oxygen
 {
